@@ -3,11 +3,14 @@ import importlib
 import os
 import subprocess
 import sys
-from typing import Any
+
+# Ensure we always run from the root of the repository
+if os.getcwd() != os.path.dirname(__file__):
+    os.chdir(os.path.dirname(__file__))
 
 # checking if user is running pytest without installing test dependencies:
 missing = []
-for module in ["ansible", "black", "flake8", "flaky", "mypy", "pylint"]:
+for module in ["ansible", "black", "flake8", "mypy", "pylint"]:
     if not importlib.util.find_spec(module):
         missing.append(module)
 if missing:
@@ -17,21 +20,10 @@ if missing:
     )
     sys.exit(1)
 # we need to be sure that we have the requirements installed as some tests
-# might depend on these.
+# might depend on these. This approach is compatible with GHA caching.
 try:
-    from ansible_compat.prerun import get_cache_dir
-
-    cache_dir = get_cache_dir(".")
     subprocess.check_output(
-        [
-            "ansible-galaxy",
-            "collection",
-            "install",
-            "-p",
-            f"{cache_dir}/collections",
-            "-r",
-            "requirements.yml",
-        ],
+        ["./tools/install-reqs.sh"],
         stderr=subprocess.PIPE,
         text=True,
     )
@@ -44,11 +36,9 @@ from ansible.module_utils.common.yaml import (  # pylint: disable=wrong-import-p
     HAS_LIBYAML,
 )
 
-if not HAS_LIBYAML and sys.version_info >= (3, 9, 0):
+if not HAS_LIBYAML:
     # While presence of libyaml is not required for runtime, we keep this error
     # fatal here in order to be sure that we spot libyaml errors during testing.
-    #
-    # For 3.8.x we do not do this check, as libyaml does not have an arm64 build for py38.
     print(
         "FATAL: For testing, we require pyyaml to be installed with its native extension, missing it would make testing 3x slower and risk missing essential bugs.",
         file=sys.stderr,
