@@ -6,8 +6,9 @@ import logging
 import os
 import sys
 from argparse import Namespace
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Any, Callable, Sequence
+from typing import Any, Callable
 
 from ansiblelint.config import DEFAULT_KINDS, DEFAULT_WARN_LIST, PROFILES
 from ansiblelint.constants import (
@@ -22,6 +23,7 @@ from ansiblelint.file_utils import (
     guess_project_dir,
     normpath,
 )
+from ansiblelint.loaders import IGNORE_FILE
 from ansiblelint.schemas.main import validate_file_schema
 from ansiblelint.yaml_utils import clean_json
 
@@ -56,6 +58,11 @@ def expand_to_normalized_paths(
 def load_config(config_file: str) -> dict[Any, Any]:
     """Load configuration from disk."""
     config_path = None
+
+    if config_file == "/dev/null":
+        _logger.debug("Skipping config file as it was set to /dev/null")
+        return {}
+
     if config_file:
         config_path = os.path.abspath(config_file)
         if not os.path.exists(config_path):
@@ -249,7 +256,6 @@ def get_cli_parser() -> argparse.ArgumentParser:
             "quiet",
             "pep8",
             "sarif",
-            "docs",  # internally used
         ],
         help="stdout formatting, json being an alias for codeclimate. (default: %(default)s)",
     )
@@ -368,6 +374,13 @@ def get_cli_parser() -> argparse.ArgumentParser:
         help="only check rules whose id/tags do not match these values. \
             e.g: --skip-list=name,run-once",
     )
+    parser.add_argument(
+        "--generate-ignore",
+        dest="generate_ignore",
+        action="store_true",
+        default=False,
+        help="Generate a text file '.ansible-lint-ignore' that ignores all found violations. Each line contains filename and rule id separated by a space.",
+    )
     parser.add_argument(
         "-w",
         "--warn-list",
@@ -413,6 +426,14 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="config_file",
         help="Specify configuration file to use. By default it will look for '.ansible-lint' or '.config/ansible-lint.yml'",
     )
+    parser.add_argument(
+        "-i",
+        "--ignore-file",
+        dest="ignore_file",
+        type=Path,
+        default=None,
+        help=f"Specify ignore file to use. By default it will look for '{IGNORE_FILE.default}' or '{IGNORE_FILE.alternative}'",
+    )
     parser.add_argument(
         "--offline",
         dest="offline",
@@ -532,7 +553,6 @@ def get_config(arguments: list[str]) -> Namespace:
         "brief",
         "full",
         "md",
-        "docs",
     ]:
         parser.error(
             f"argument -f: invalid choice: '{options.format}'. "
