@@ -19,7 +19,7 @@ class NoFreeFormRule(AnsibleLintRule):
     id = "no-free-form"
     description = "Avoid free-form inside files as it can produce subtile bugs."
     severity = "MEDIUM"
-    tags = ["syntax", "risk", "experimental"]
+    tags = ["syntax", "risk"]
     version_added = "v6.8.0"
     needs_raw_task = True
     cmd_shell_re = re.compile(
@@ -84,7 +84,6 @@ class NoFreeFormRule(AnsibleLintRule):
 
 
 if "pytest" in sys.modules:  # noqa: C901
-
     import pytest
 
     from ansiblelint.rules import RulesCollection  # pylint: disable=ungrouped-imports
@@ -94,7 +93,7 @@ if "pytest" in sys.modules:  # noqa: C901
         ("file", "expected"),
         (
             pytest.param("examples/playbooks/rule-no-free-form-pass.yml", 0, id="pass"),
-            pytest.param("examples/playbooks/rule-no-free-form-fail.yml", 2, id="fail"),
+            pytest.param("examples/playbooks/rule-no-free-form-fail.yml", 3, id="fail"),
         ),
     )
     def test_rule_no_free_form(
