@@ -26,12 +26,11 @@ import inspect
 import logging
 import os
 import re
-import warnings
 from argparse import Namespace
-from collections.abc import ItemsView, Mapping
+from collections.abc import ItemsView, Mapping, Sequence
 from functools import lru_cache
 from pathlib import Path
-from typing import Any, Callable, Generator, Sequence
+from typing import Any, Callable
 
 import yaml
 from ansible.errors import AnsibleError, AnsibleParserError
@@ -347,7 +346,6 @@ def _taskshandlers_children(
             rule=RuntimeErrorRule(),
         )
     for task_handler in v:
-
         # ignore empty tasks, `-`
         if not task_handler:
             continue
@@ -406,9 +404,7 @@ def _get_task_handler_children_for_tasks_or_playbooks(
 
     # Include the FQCN task names as this happens before normalize
     for task_handler_key in INCLUSION_ACTION_NAMES:
-
         with contextlib.suppress(KeyError):
-
             # ignore empty tasks
             if not task_handler:  # pragma: no branch
                 continue
@@ -521,11 +517,6 @@ def _look_for_role_files(
     return results
 
 
-def _kv_to_dict(v: str) -> dict[str, Any]:
-    (command, args, kwargs) = tokenize(v)
-    return {"__ansible_module__": command, "__ansible_arguments__": args, **kwargs}
-
-
 def _sanitize_task(task: dict[str, Any]) -> dict[str, Any]:
     """Return a stripped-off task structure compatible with new Ansible.
 
@@ -547,7 +538,7 @@ def _extract_ansible_parsed_keys_from_task(
     keys: tuple[str, ...],
 ) -> dict[str, Any]:
     """Return a dict with existing key in task."""
-    for (k, v) in list(task.items()):
+    for k, v in list(task.items()):
         if k in keys:
             # we don't want to re-assign these values, which were
             # determined by the ModuleArgsParser() above
@@ -609,18 +600,6 @@ def normalize_task_v2(task: dict[str, Any]) -> dict[str, Any]:
         "__ansible_module_original__": action_unnormalized,
     }
 
-    if "_raw_params" in arguments:
-        # Doing a split here is really bad as it would break jinja2 templating
-        # parsing of the template must happen before any kind of split.
-        result["action"]["__ansible_arguments__"] = [arguments["_raw_params"]]
-        del arguments["_raw_params"]
-    else:
-        result["action"]["__ansible_arguments__"] = []
-
-    if "argv" in arguments and not result["action"]["__ansible_arguments__"]:
-        result["action"]["__ansible_arguments__"] = arguments["argv"]
-        del arguments["argv"]
-
     result["action"].update(arguments)
     return result
 
@@ -651,13 +630,14 @@ def task_to_str(task: dict[str, Any]) -> str:
         not in [
             "__ansible_module__",
             "__ansible_module_original__",
-            "__ansible_arguments__",
+            "_raw_params",
             LINE_NUMBER_KEY,
             FILENAME_KEY,
         ]
     ]
 
-    for item in action.get("__ansible_arguments__", []):
+    # breakpoint()
+    for item in action.get("_raw_params", []):
         args.append(str(item))
 
     return f"{action['__ansible_module__']} {' '.join(args)}"
@@ -772,13 +752,21 @@ def parse_yaml_linenumbers(  # noqa: max-complexity: 12
     return result
 
 
+def get_cmd_args(task: dict[str, Any]) -> str:
+    """Extract the args from a cmd task as a string."""
+    if "cmd" in task["action"]:
+        args = task["action"]["cmd"]
+    else:
+        args = task["action"].get("_raw_params", [])
+    if not isinstance(args, str):
+        return " ".join(args)
+    return args
+
+
 def get_first_cmd_arg(task: dict[str, Any]) -> Any:
     """Extract the first arg from a cmd task."""
     try:
-        if "cmd" in task["action"]:
-            first_cmd_arg = task["action"]["cmd"].split()[0]
-        else:
-            first_cmd_arg = task["action"]["__ansible_arguments__"][0].split()[0]
+        first_cmd_arg = get_cmd_args(task).split()[0]
     except IndexError:
         return None
     return first_cmd_arg
@@ -787,10 +775,7 @@ def get_first_cmd_arg(task: dict[str, Any]) -> Any:
 def get_second_cmd_arg(task: dict[str, Any]) -> Any:
     """Extract the second arg from a cmd task."""
     try:
-        if "cmd" in task["action"]:
-            second_cmd_arg = task["action"]["cmd"].split()[1]
-        else:
-            second_cmd_arg = task["action"]["__ansible_arguments__"][0].split()[1]
+        second_cmd_arg = get_cmd_args(task).split()[1]
     except IndexError:
         return None
     return second_cmd_arg
@@ -848,9 +833,7 @@ def get_lintables(
             lintable = Lintable(arg)
             lintables.append(lintable)
     else:
-
         for filename in discover_lintables(opts):
-
             path = Path(filename)
             # skip exclusions
             try:
@@ -894,26 +877,3 @@ def _extend_with_roles(lintables: list[Lintable]) -> None:
 def convert_to_boolean(value: Any) -> bool:
     """Use Ansible to convert something to a boolean."""
     return bool(boolean(value))
-
-
-def nested_items(
-    data: dict[Any, Any] | list[Any], parent: str = ""
-) -> Generator[tuple[Any, Any, str], None, None]:
-    """Iterate a nested data structure."""
-    warnings.warn(
-        "Call to deprecated function ansiblelint.utils.nested_items. "
-        "Use ansiblelint.yaml_utils.nested_items_path instead.",
-        category=DeprecationWarning,
-        stacklevel=2,
-    )
-    if isinstance(data, dict):
-        for k, v in data.items():
-            yield k, v, parent
-            # pylint: disable=redefined-outer-name
-            for k, v, returned_parent in nested_items(v, k):
-                yield k, v, returned_parent
-    if isinstance(data, list):
-        for item in data:
-            yield "list-item", item, parent
-            for k, v, returned_parent in nested_items(item):
-                yield k, v, returned_parent
